<?php

require_once 'backend/error_reporting_config.php';

session_start();
define("OVS", true); // Im a simple security man. I only want requires to be called by me.
require_once 'backend/helpers.php';

$login = false;

if(isset($_SESSION['login']) && $_SESSION['login'] === 1) {
    
    $ip = getUserIP();
    if($_SESSION['ip'] != $ip) {
        
        header('Location: logout.php?error=ipc');
        exit;
    }
    $login = true;
}

if($login) {
    
    header('Location: vote.php');
    exit;
}

// Database connection is established here for better performance
require_once 'backend/connect.php';

// Someone is logging in
if($_SERVER['REQUEST_METHOD'] == 'POST') {
    
    $cc = null;
    $nm = null;
    $sm = null;
    $by = null;
    
    if(isset($_POST['cc']) && isset($_POST['nm']) && isset($_POST['sm']) && isset($_POST['by'])) {
        
        $cc = filter_var(trim($_POST['cc']), FILTER_SANITIZE_SPECIAL_CHARS);
        $nm = filter_var(trim($_POST['nm']), FILTER_SANITIZE_SPECIAL_CHARS);
        $sm = filter_var(trim($_POST['sm']), FILTER_SANITIZE_SPECIAL_CHARS);
        $by = filter_var(trim($_POST['by']), FILTER_SANITIZE_SPECIAL_CHARS);
        
        // Never trust user input validate it always!
        if(strpos($cc, '&') !== false || strpos($nm, '&') !== false || strpos($sm, '&') !== false || strpos($by, '&') !== false) {
            
            header('Location: index.php?error=invalidInputs');
            exit;
        }
        
        $token = sha1(base64_encode(md5($nm . ' ' . $sm . ' ' . $cc . ' ' . $cc . ' ' . base64_encode($cc) . strrev($sm . ' ' . $nm)))); // Generate user token from summary of user's information
        
        if(isset($_COOKIE['acm368_OVS']) && !empty($_COOKIE['acm368_OVS'])) {
            
            $tokenval = $_COOKIE['acm368_OVS'];
            if($tokenval != $token) {
                
                header('Location: index.php?error=message&msg=' . urlencode("You voted from this device before!"));
                exit;
            }
        }
        
        setcookie("acm368_OVS", $token);
        
        $params = [];
        $params['name'] = $nm;
        $params['surname'] = $sm;
        $params['by'] = $by;
        $params['ni'] = $cc;
        
        $res = nviapi($params);
        
        if(!$res[0]) {
            
            header('Location: index.php?error=message&msg=' . urlencode($res[1]));
            exit;
        }
        
        $stmt = $pdo->prepare("SELECT voted_at FROM votedpersons WHERE id = :id");
        $stmt->bindParam(':id', $cc, PDO::PARAM_STR);
        $stmt->execute();
        if($stmt->rowCount() > 0) {
            
            unset($stmt);
            unset($pdo);
            header('Location: index.php?error=alreadyvoted');
            exit;
        }
        
        $_SESSION['login'] = 1;
        $_SESSION['uid'] = $cc;
        $_SESSION['info'] = $params;
        $_SESSION['ip'] = getUserIP();
        
        unset($stmt);
        unset($pdo);
        header('Location: vote.php');
        exit;
    }
}

// Define if no errors were defined before
$error = '';
if(isset($_GET['error']) && !empty($_GET['error'])) {
    
    $error = trim($_GET['error']);
    switch($error) {
        
        case 'message':
            $error = $_GET['msg'];
            break;
        case 'invalidInputs':
            $error = 'Please check your inputs';
            break;
        case 'alreadyvoted':
            $error = 'You already voted';
            break;
        default:
            $error = 'Unknown error occured. Please try again later';
            break;
    }
}
?>
<!DOCTYPE html>
<html>
  <head>
    <title>Online Voting System</title>
    <link href="https://fonts.googleapis.com/css?family=Roboto:300,400,500,700" rel="stylesheet">
    <style>
      html, body {
      display: flex;
      justify-content: center;
      font-family: Roboto, Arial, sans-serif;
      font-size: 15px;
      }
      form {
      border: 5px solid #f1f1f1;
      }
      input[type=text], input[type=password] {
      width: 100%;
      padding: 16px 8px;
      margin: 8px 0;
      display: inline-block;
      border: 1px solid #ccc;
      box-sizing: border-box;
      }
      button {
      background-color: #8ebf42;
      color: white;
      padding: 14px 0;
      margin: 10px 0;
      border: none;
      cursor: grabbing;
      width: 100%;
      }
      h1 {
      text-align:center;
      fone-size:18;
      }
      button:hover {
      opacity: 0.8;
      }
      .formcontainer {
      text-align: left;
      margin: 24px 50px 12px;
      }
      .container {
      padding: 16px 0;
      text-align:left;
      }
      span.psw {
      float: right;
      padding-top: 0;
      padding-right: 15px;
      }
      /* Change styles for span on extra small screens */
      @media screen and (max-width: 300px) {
      span.psw {
      display: block;
      float: none;
      }
    </style>
  </head>
  <body>
    <form method="post">
      <h1>Voting System Entrance</h1>
      <div class="formcontainer">
      <hr/>
      <h4 style="color:red;"><b><?=htmlspecialchars($error);?></b></h4>
      <div class="container">
        <label for="tckn"><strong>Turkish National Identifier Number</strong></label>
        <input type="password" id="tckn" placeholder="11 digit citizenship code" name="cc" required>
        
        <label for="nm"><strong>Name(s)</strong></label>
        <input type="text" id="nm" placeholder="Name" name="nm" required>
        
        <label for="sm"><strong>Surname</strong></label>
        <input type="text" id="sm" placeholder="Surname" name="sm" required>
        
        <label for="psw"><strong>Year of Birth</strong></label>
        <input type="password" id="psw" placeholder="2000" name="by" required>
      </div>
      <p>By clicking proceed button below, I accept to share my national identification number, my birth year and my full name with the website having the domain <b>acm368.tr.ht</b>, which will be stored on the database of the website having, domain of <b>acm368.tr.ht</b> for tracking of the voting process, until the voting ends.</p>
      <button type="submit">Proceed</button>
    </form>
  </body>
</html>